Interfaces, exceptions and utils
================================

Connection Client Interface
---------------------------

.. automodule:: bleak.backends.client
    :members:

Scanning Client Interface
-------------------------

.. automodule:: bleak.backends.scanner
    :members:

Interface for BLE devices
-------------------------

Generated by :py:meth:`bleak.discover` and :py:class:`bleak.backends.scanning.BaseBleakScanner`.

.. automodule:: bleak.backends.device
    :members:

Interfaces for GATT objects
---------------------------

.. automodule:: bleak.backends.service
    :members:

.. automodule:: bleak.backends.characteristic
    :members:

.. automodule:: bleak.backends.descriptor
    :members:


Exceptions
----------

.. automodule:: bleak.exc
    :members:

Utilities
---------

.. automodule:: bleak.utils
    :members:

.. automodule:: bleak.uuids
    :members:
